package com.example.spinnerdemo_kotlin_s20

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.view.View
import android.widget.Button
import android.widget.Spinner
import android.widget.TextView
import android.widget.AdapterView
import android.widget.Toast
import android.widget.ArrayAdapter

class MainActivity : AppCompatActivity() {


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        // array of steak thicknesses
        var thicknesses = arrayOf(0.5, 0.75, 1.0, 1.25, 1.5, 1.75, 2.0)

        // get array from res/values/strings.xml
        val done_numb = resources.getIntArray(R.array.doneness_number)

        // connect interface to code
        val btnCalc = findViewById<Button>(R.id.btnCalc)
        val tvResult = findViewById<TextView>(R.id.tvResult)
        val spDoneness = findViewById<Spinner>(R.id.spDoneness)
        val spThickness = findViewById<Spinner>(R.id.spThickness)

        //****************************************************************************************************
        // populate "Doneness" spinner from array define in strings.xml in res/values/
        // populating a spinner uses an Array Adapter
        val aaDoneness = ArrayAdapter.createFromResource(this, R.array.doneness_desc, android.R.layout.simple_spinner_item)
        spDoneness.adapter = aaDoneness

        // spinner event handler  -- requires two methods onItemSelected & onNothingSelected
        spDoneness.onItemSelectedListener = object : AdapterView.OnItemSelectedListener {
            override fun onItemSelected(adapterView: AdapterView<*>, view: View, i: Int, l: Long) {
                val tvUserItem = view as TextView
                Toast.makeText(applicationContext, "You chose " + tvUserItem.text.toString(), Toast.LENGTH_SHORT).show()
                tvResult.text = "-------------------"  //clear out any previous result
            }

            //need following even if it contains no explicit code
            override fun onNothingSelected(adapterView: AdapterView<*>) {}
        }

        //************************************************************************************************************
        // populate the "Thickness" array from a coded array
        val aaThickness = ArrayAdapter(this, android.R.layout.simple_spinner_item, thicknesses)
        aaThickness.setDropDownViewResource(android.R.layout.simple_spinner_item) // The drop down view
        spThickness.adapter = aaThickness

        spThickness.onItemSelectedListener = object : AdapterView.OnItemSelectedListener {
            override fun onItemSelected(adapterView: AdapterView<*>, view: View, i: Int, l: Long) {
                val tvUserItem = view as TextView
                Toast.makeText(applicationContext, "You chose " + tvUserItem.text.toString(), Toast.LENGTH_SHORT).show()
                tvResult.text = "-------------------"
            }

            override fun onNothingSelected(adapterView: AdapterView<*>) {}
        }

        //**********************************************************************************************************
        // handle button click implicit version
        btnCalc.setOnClickListener {
            val userDoneIndex = spDoneness.selectedItemId.toInt() //get selected index
            // .selectedItemId will be a long -- but convert to integer to use in parallel array
            // rare 2, medium rare 3, medium 4, medium well 5, well done 6

            val userThickness = spThickness.selectedItem.toString().toDouble()  //get selected item

            val cooktime = done_numb[ userDoneIndex] + userThickness* 4.0
            tvResult.text = "Cook " + String.format("%.1f", cooktime) + " minutes"
        }

    }//end onCreate
}//end MainActivity class

